@@ -425,6 +425,29 @@ class TembaClientTest(TembaTest):
             },
         )
 
+    def test_get_definitions(self, mock_request):
+        mock_request.return_value = MockResponse(200, self.read_json("definitions"))
+
+        # check with all params
+        definitions = self.client.get_definitions(
+            flows=["04a4752b-0f49-480e-ae60-3a3f2bea485c", "ffce0fbb-4fe1-4052-b26a-91beb2ebae9a"],
+            campaigns=[],
+            dependencies=False,
+        )
+
+        self.assertRequest(
+            mock_request,
+            "get",
+            "definitions",
+            params={
+                "flow": ["04a4752b-0f49-480e-ae60-3a3f2bea485c", "ffce0fbb-4fe1-4052-b26a-91beb2ebae9a"],
+                "campaign": [],
+                "dependencies": 0,
+            },
+        )
+
+        self.assertEqual(definitions.version, "10.1")
+
     def test_get_fields(self, mock_request):
         # check no params
         mock_request.return_value = MockResponse(200, self.read_json("fields"))
@@ -720,7 +743,6 @@ class TembaClientTest(TembaTest):
         self.assertEqual(len(results[0].values), 2)
         self.assertEqual(results[0].values["color"].value, "blue")
         self.assertEqual(results[0].values["color"].category, "Blue")
-        self.assertEqual(results[0].values["color"].input, "it is blue")
         self.assertEqual(results[0].values["color"].name, "color")
         self.assertEqual(results[0].values["color"].node, "fc32aeb0-ac3e-42a8-9ea7-10248fdf52a1")
         self.assertEqual(results[0].values["color"].time, datetime(2015, 11, 11, 13, 3, 51, 635662, tzone.utc))
